@@ -1,7 +1,7 @@
 #
 # This file is part of ElasticSearchX-Model
 #
-# This software is Copyright (c) 2012 by Moritz Onken.
+# This software is Copyright (c) 2013 by Moritz Onken.
 #
 # This is free software, licensed under:
 #
@@ -9,7 +9,7 @@
 #
 package ElasticSearchX::Model::Document::Trait::Class;
 {
-  $ElasticSearchX::Model::Document::Trait::Class::VERSION = '0.1.4';
+  $ElasticSearchX::Model::Document::Trait::Class::VERSION = '0.1.5';
 }
 
 # ABSTRACT: Trait that extends the meta class of a document class
@@ -103,7 +103,7 @@ sub add_property {
     my ($self, $name) = (shift, shift);
     Moose->throw_error('Usage: has \'name\' => ( key => value, ... )')
         if @_ % 2 == 1;
-    my %options = ( definition_context => Moose::Util::_caller_info(), @_ );
+    my %options = ( definition_context => _caller_info(), @_ );
     $options{traits} ||= [];
     push(
         @{ $options{traits} },
@@ -120,6 +120,13 @@ sub add_property {
     $self->add_attribute( $_, %options ) for @$attrs;
 }
 
+sub _caller_info {
+    my $level = @_ ? ( $_[0] + 1 ) : 2;
+    my %info;
+    @info{qw(package file line)} = caller($level);
+    return \%info;
+}
+
 sub all_properties_loaded {
     my ($self, $instance) = @_;
     my $loaded = $instance->_loaded_attributes;
@@ -203,8 +210,8 @@ sub inflate_result {
 
 1;
 
-
 __END__
+
 =pod
 
 =head1 NAME
@@ -213,7 +220,7 @@ ElasticSearchX::Model::Document::Trait::Class - Trait that extends the meta clas
 
 =head1 VERSION
 
-version 0.1.4
+version 0.1.5
 
 =head1 ATTRIBUTES
 
@@ -288,11 +295,10 @@ Moritz Onken
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2012 by Moritz Onken.
+This software is Copyright (c) 2013 by Moritz Onken.
 
 This is free software, licensed under:
 
   The (three-clause) BSD License
 
 =cut
-
